Class: SourceRoute::Wrapper

Inherits:
Object
  • Object
show all
Extended by:
Forwardable
Includes:
Singleton
Defined in:
lib/source_route/wrapper.rb

Defined Under Namespace

Classes: Condition

Constant Summary collapse

TRACE_POINT_METHODS =
[:defined_class, :method_id, :path, :lineno]

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeWrapper

Returns a new instance of Wrapper.



62
63
64
# File 'lib/source_route/wrapper.rb', line 62

def initialize
  reset
end

Instance Attribute Details

#conditionObject

Returns the value of attribute condition.



8
9
10
# File 'lib/source_route/wrapper.rb', line 8

def condition
  @condition
end

#tpObject

Returns the value of attribute tp.



8
9
10
# File 'lib/source_route/wrapper.rb', line 8

def tp
  @tp
end

#tp_result_chainObject (readonly)

Returns the value of attribute tp_result_chain.



9
10
11
# File 'lib/source_route/wrapper.rb', line 9

def tp_result_chain
  @tp_result_chain
end

#tp_self_cachesObject (readonly)

Returns the value of attribute tp_self_caches.



9
10
11
# File 'lib/source_route/wrapper.rb', line 9

def tp_self_caches
  @tp_self_caches
end

Instance Method Details

#jsonify_eventsObject



94
95
96
# File 'lib/source_route/wrapper.rb', line 94

def jsonify_events
  JSON.dump(@condition.events.map(&:to_s))
end

#jsonify_tp_result_chainObject



98
99
100
# File 'lib/source_route/wrapper.rb', line 98

def jsonify_tp_result_chain
  JSON.dump(tp_result_chain.stringify)
end

#jsonify_tp_self_cachesObject



102
103
104
# File 'lib/source_route/wrapper.rb', line 102

def jsonify_tp_self_caches
  JSON.dump(tp_self_caches.clone.map(&:to_s))
end

#resetObject



66
67
68
69
70
71
72
# File 'lib/source_route/wrapper.rb', line 66

def reset
  @tp.disable if defined? @tp
  @condition = Condition.new
  @tp_result_chain = TpResultChain.new
  @tp_self_caches = []
  self
end

#traceObject



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/source_route/wrapper.rb', line 74

def trace
  # dont wanna init it in tp block, cause tp block could run thousands of times in one cycle trace
  tp_result = GenerateResult.new(self)
  tp_filter = TpFilter.new(condition)

  track = TracePoint.new *condition.events do |tp|

    next if tp_filter.block_it?(tp)

    unless condition.result_config.format.is_a? Proc
      ret_data = tp_result.build(tp)
      @tp_result_chain.push(ret_data)
    end

    tp_result.output(tp)
  end
  track.enable
  self.tp = track
end